==> service_layer_rest-0.1.0.gem: app/controllers/service_layer_rest/authorizations_controller.rb <==
module ServiceLayerRest
  class AuthorizationsController < ApplicationController
    include Base
    include Dll

    def login
      invalid_key = check_params([:username, :password], [:mandantid])
      invalid_key = :authtype if params[:authtype].nil? && invalid_key.blank?
      return render bad_params_for_render(invalid_key) unless invalid_key.blank?

      begin
        response_string, string_pointer = ServiceLayerDll.login(
          params[:username],
          params[:password],
          params[:authtype],
          params[:mandantid].to_i
        )
        ServiceLayerDll.free_string(string_pointer)

        render_json = parse_response_string_for_render(response_string)

        if render_json[:status] == Rack::Utils.status_code(:ok) && $fake_data
          employees = render_json[:json][:data]["employees"]
          if employees.present? && employees["items"].present? && employees["items"].length > 0
            employee_2 = employees["items"][0].clone
            employee_2["mitarbeiterName"] = employee_2["mitarbeiterName"] + " Nr. 2"
            employees["items"].push employee_2
            employees["listHelper"] = 2
          end
          render_json[:json][:data]["employees"] = employees.present? ? employees : []
        end

        render render_json
      rescue Exception => e
        render parse_exception_for_render(e)
      end
    end

    def get_employee_rights
      invalid_key = check_params([:fct_code], [])
      return render bad_params_for_render(invalid_key) unless invalid_key.blank?

      begin
        response_string, string_pointer = ServiceLayerDll.get_employee_rights(
          current_user.as_json,
          params[:fct_code]
        )
        ServiceLayerDll.free_string(string_pointer)

        employee_rights, state = extract_data_and_state_from_response_string(response_string)

        if state != Rack::Utils.status_code(:ok) || employee_rights.nil?
            return render parse_response_string_for_render(response_string)
        end

        # Extract the necessary values for the rights.
        user_config = employee_rights[Constants::RIGHTS_USER_CONFIG_KEY]
        function_rights = employee_rights[Constants::RIGHTS_FUNCTION_RIGHTS_KEY]

        max_day_change_duty = user_config[Constants::RIGHTS_MAX_DAY_CHANGE_DUTY_KEY]
        max_day_change_standby = user_config[Constants::RIGHTS_MAX_DAY_CHANGE_STANDBY_KEY]
        max_day_change_timesheet = user_config[Constants::RIGHTS_MAX_DAY_CHANGE_TIMESHEET_KEY]

        workflow_vacation = user_config[Constants::RIGHTS_WORKFLOW_VACATION_KEY]
        workflow_booking_correction = user_config[Constants::RIGHTS_WORKFLOW_BOOKING_CORRECTION_KEY]
        workflow_overtime_reduction = user_config[Constants::RIGHTS_WORKFLOW_OVERTIME_REDUCTION_KEY]
        workflow_ill_without_disabled = user_config[Constants::RIGHTS_WORKFLOW_ILL_WITHOUT_DISABLEDKEY]

        rights_hash = {
            Constants::RIGHTS_MAX_DAY_CHANGE_DUTY_KEY => max_day_change_duty,
            Constants::RIGHTS_MAX_DAY_CHANGE_STANDBY_KEY => max_day_change_standby,
            Constants::RIGHTS_MAX_DAY_CHANGE_TIMESHEET_KEY => max_day_change_timesheet,
            Constants::RIGHTS_WORKFLOW_VACATION_KEY => workflow_vacation,
            Constants::RIGHTS_WORKFLOW_BOOKING_CORRECTION_KEY => workflow_booking_correction,
            Constants::RIGHTS_WORKFLOW_OVERTIME_REDUCTION_KEY => workflow_overtime_reduction,
            Constants::RIGHTS_WORKFLOW_ILL_WITHOUT_DISABLEDKEY => workflow_ill_without_disabled,
            Constants::RIGHTS_START_KEY => false,
            Constants::RIGHTS_DUTY_INPUT_KEY => false,
            Constants::RIGHTS_DUTY_WISH_KEY => false,
            Constants::RIGHTS_STANDBY_INPUT_KEY => false,
            Constants::RIGHTS_STANDBY_WISH_KEY => false,
            Constants::RIGHTS_PLANAREA_VISIBLE_KEY => false,
            Constants::RIGHTS_CHANGE_APPROVED_DUTY_TOKENS_KEY => false,
            Constants::RIGHTS_CHANGE_APPROVED_STANDBY_TOKENS_KEY => false,
            Constants::RIGHTS_WARNINGS_VISIBLE_KEY => false,
            Constants::RIGHTS_ONLY_APPROVED_DUTY_PLANS_VISIBLE_KEY => false,
            Constants::RIGHTS_TIMESHEET_KEY => false,
            Constants::RIGHTS_DAY_INSPECTOR_KEY => false,
            Constants::RIGHTS_CUMULATION_KEY => false,
            Constants::RIGHTS_FUTURE_DISABLED_KEY => false
        }

        rights_key_enum_array = [
            [Constants::RIGHTS_START, Constants::RIGHTS_START_KEY],
            [Constants::RIGHTS_DUTY_INPUT, Constants::RIGHTS_DUTY_INPUT_KEY],
            [Constants::RIGHTS_DUTY_WISH, Constants::RIGHTS_DUTY_WISH_KEY],
            [Constants::RIGHTS_STANDBY_INPUT, Constants::RIGHTS_STANDBY_INPUT_KEY],
            [Constants::RIGHTS_STANDBY_WISH, Constants::RIGHTS_STANDBY_WISH_KEY],
            [Constants::RIGHTS_PLANAREA_VISIBLE, Constants::RIGHTS_PLANAREA_VISIBLE_KEY],
            [Constants::RIGHTS_CHANGE_APPROVED_DUTY_TOKENS, Constants::RIGHTS_CHANGE_APPROVED_DUTY_TOKENS_KEY],
            [Constants::RIGHTS_CHANGE_APPROVED_STANDBY_TOKENS, Constants::RIGHTS_CHANGE_APPROVED_STANDBY_TOKENS_KEY],
            [Constants::RIGHTS_WARNINGS_VISIBLE, Constants::RIGHTS_WARNINGS_VISIBLE_KEY],
            [Constants::RIGHTS_ONLY_APPROVED_DUTY_PLANS_VISIBLE, Constants::RIGHTS_ONLY_APPROVED_DUTY_PLANS_VISIBLE_KEY],
            [Constants::RIGHTS_TIMESHEET, Constants::RIGHTS_TIMESHEET_KEY],
            [Constants::RIGHTS_DAY_INSPECTOR, Constants::RIGHTS_DAY_INSPECTOR_KEY],
            [Constants::RIGHTS_CUMULATION, Constants::RIGHTS_CUMULATION_KEY],
            [Constants::RIGHTS_FUTURE_DISABLED, Constants::RIGHTS_FUTURE_DISABLED_KEY]
        ]

        function_rights_array = function_rights[Constants::ITEMS_KEY]

        function_rights_array.each do |rights_array|
            rights_key_enum_array.each do |rights_enum, rights_key|
                if rights_array.include? rights_enum
                    rights_hash[rights_key] = true
                end
            end
        end

        render create_json_response(:ok, THIS_SOURCE, NO_SOURCE_DETAILS, rights_hash)
      rescue Exception => e
        render parse_exception_for_render(e)
      end
    end

    def get_employee_rights_userconfig
      invalid_key = check_params([:fct_code], [])
      return render bad_params_for_render(invalid_key) unless invalid_key.blank?

      begin
        response_string, string_pointer = ServiceLayerDll.get_employee_rights_userconfig(
          current_user.as_json,
          params[:fct_code]
        )
        ServiceLayerDll.free_string(string_pointer)

        render parse_response_string_for_render(response_string)
      rescue Exception => e
        render parse_exception_for_render(e)
      end
    end

    def get_permission
      invalid_key = check_params([], [:given_fct_code, :min_right, :mandant_id, :planarea_id, :subjectarea_id])
      return render bad_params_for_render(invalid_key) unless invalid_key.blank?

      begin
        response_string, string_pointer = ServiceLayerDll.get_permission(
          current_user.as_json,
          params[:given_fct_code].to_i,
          params[:min_right].to_i,
          params[:mandant_id].to_i,
          params[:planarea_id].to_i,
          params[:subjectarea_id].to_i
        )
        ServiceLayerDll.free_string(string_pointer)

        render parse_response_string_for_render(response_string)
      rescue Exception => e
        render parse_exception_for_render(e)
      end
    end

    def get_permission_right
      invalid_key = check_params([], [:given_fct_code, :mandant_id, :planarea_id, :subjectarea_id])
      return render bad_params_for_render(invalid_key) unless invalid_key.blank?

      begin
        response_string, string_pointer = ServiceLayerDll.get_permission_right(
          current_user.as_json,
          params[:given_fct_code].to_i,
          params[:mandant_id].to_i,
          params[:planarea_id].to_i,
          params[:subjectarea_id].to_i
        )
        ServiceLayerDll.free_string(string_pointer)

        render parse_response_string_for_render(response_string)
      rescue Exception => e
        render parse_exception_for_render(e)
      end
    end

    def get_permitted_planareas
      invalid_key = check_params([], [:given_fct_code])
      return render bad_params_for_render(invalid_key) unless invalid_key.blank?

      begin
        response_string, string_pointer = ServiceLayerDll.get_permitted_planareas(
          current_user.as_json,
          params[:given_fct_code].to_i
        )
        ServiceLayerDll.free_string(string_pointer)

        render parse_response_string_for_render(response_string)
      rescue Exception => e
        render parse_exception_for_render(e)
      end
    end
  end
end

==> service_layer_rest-0.1.5.gem: app/controllers/service_layer_rest/authorizations_controller.rb <==
module ServiceLayerRest
  class AuthorizationsController < ApplicationController
    include Base
    include Dll

    def login
      invalid_key = check_params([:username, :password], [:mandantid])
      invalid_key = :authtype if params[:authtype].nil? && invalid_key.blank?
      return render bad_params_for_render(invalid_key) unless invalid_key.blank?

      begin
        response_string, string_pointer = ServiceLayerDll.login(
          params[:username],
          params[:password],
          params[:authtype],
          params[:mandantid].to_i
        )
        ServiceLayerDll.free_string(string_pointer)

        render render_json = parse_response_string_for_render(response_string)
      rescue Exception => e
        render parse_exception_for_render(e)
      end
    end

    def get_employee_rights
      invalid_key = check_params([:fct_code], [])
      return render bad_params_for_render(invalid_key) unless invalid_key.blank?

      begin
        response_string, string_pointer = ServiceLayerDll.get_employee_rights(
          current_user.as_json,
          params[:fct_code]
        )
        ServiceLayerDll.free_string(string_pointer)

        employee_rights, state = extract_data_and_state_from_response_string(response_string)

        if state != Rack::Utils.status_code(:ok) || employee_rights.nil?
            return render parse_response_string_for_render(response_string)
        end

        # Extract the necessary values for the rights.
        user_config = employee_rights[Constants::RIGHTS_USER_CONFIG_KEY]
        function_rights = employee_rights[Constants::RIGHTS_FUNCTION_RIGHTS_KEY]

        max_day_change_duty = user_config[Constants::RIGHTS_MAX_DAY_CHANGE_DUTY_KEY]
        max_day_change_standby = user_config[Constants::RIGHTS_MAX_DAY_CHANGE_STANDBY_KEY]
        max_day_change_timesheet = user_config[Constants::RIGHTS_MAX_DAY_CHANGE_TIMESHEET_KEY]

        workflow_vacation = user_config[Constants::RIGHTS_WORKFLOW_VACATION_KEY]
        workflow_booking_correction = user_config[Constants::RIGHTS_WORKFLOW_BOOKING_CORRECTION_KEY]
        workflow_overtime_reduction = user_config[Constants::RIGHTS_WORKFLOW_OVERTIME_REDUCTION_KEY]
        workflow_ill_without_disabled = user_config[Constants::RIGHTS_WORKFLOW_ILL_WITHOUT_DISABLEDKEY]

        rights_hash = {
            Constants::RIGHTS_MAX_DAY_CHANGE_DUTY_KEY => max_day_change_duty,
            Constants::RIGHTS_MAX_DAY_CHANGE_STANDBY_KEY => max_day_change_standby,
            Constants::RIGHTS_MAX_DAY_CHANGE_TIMESHEET_KEY => max_day_change_timesheet,
            Constants::RIGHTS_WORKFLOW_VACATION_KEY => workflow_vacation,
            Constants::RIGHTS_WORKFLOW_BOOKING_CORRECTION_KEY => workflow_booking_correction,
            Constants::RIGHTS_WORKFLOW_OVERTIME_REDUCTION_KEY => workflow_overtime_reduction,
            Constants::RIGHTS_WORKFLOW_ILL_WITHOUT_DISABLEDKEY => workflow_ill_without_disabled,
            Constants::RIGHTS_START_KEY => false,
            Constants::RIGHTS_DUTY_INPUT_KEY => false,
            Constants::RIGHTS_DUTY_WISH_KEY => false,
            Constants::RIGHTS_STANDBY_INPUT_KEY => false,
            Constants::RIGHTS_STANDBY_WISH_KEY => false,
            Constants::RIGHTS_PLANAREA_VISIBLE_KEY => false,
            Constants::RIGHTS_CHANGE_APPROVED_DUTY_TOKENS_KEY => false,
            Constants::RIGHTS_CHANGE_APPROVED_STANDBY_TOKENS_KEY => false,
            Constants::RIGHTS_WARNINGS_VISIBLE_KEY => false,
            Constants::RIGHTS_ONLY_APPROVED_DUTY_PLANS_VISIBLE_KEY => false,
            Constants::RIGHTS_TIMESHEET_KEY => false,
            Constants::RIGHTS_DAY_INSPECTOR_KEY => false,
            Constants::RIGHTS_CUMULATION_KEY => false,
            Constants::RIGHTS_FUTURE_DISABLED_KEY => false
        }

        rights_key_enum_array = [
            [Constants::RIGHTS_START, Constants::RIGHTS_START_KEY],
            [Constants::RIGHTS_DUTY_INPUT, Constants::RIGHTS_DUTY_INPUT_KEY],
            [Constants::RIGHTS_DUTY_WISH, Constants::RIGHTS_DUTY_WISH_KEY],
            [Constants::RIGHTS_STANDBY_INPUT, Constants::RIGHTS_STANDBY_INPUT_KEY],
            [Constants::RIGHTS_STANDBY_WISH, Constants::RIGHTS_STANDBY_WISH_KEY],
            [Constants::RIGHTS_PLANAREA_VISIBLE, Constants::RIGHTS_PLANAREA_VISIBLE_KEY],
            [Constants::RIGHTS_CHANGE_APPROVED_DUTY_TOKENS, Constants::RIGHTS_CHANGE_APPROVED_DUTY_TOKENS_KEY],
            [Constants::RIGHTS_CHANGE_APPROVED_STANDBY_TOKENS, Constants::RIGHTS_CHANGE_APPROVED_STANDBY_TOKENS_KEY],
            [Constants::RIGHTS_WARNINGS_VISIBLE, Constants::RIGHTS_WARNINGS_VISIBLE_KEY],
            [Constants::RIGHTS_ONLY_APPROVED_DUTY_PLANS_VISIBLE, Constants::RIGHTS_ONLY_APPROVED_DUTY_PLANS_VISIBLE_KEY],
            [Constants::RIGHTS_TIMESHEET, Constants::RIGHTS_TIMESHEET_KEY],
            [Constants::RIGHTS_DAY_INSPECTOR, Constants::RIGHTS_DAY_INSPECTOR_KEY],
            [Constants::RIGHTS_CUMULATION, Constants::RIGHTS_CUMULATION_KEY],
            [Constants::RIGHTS_FUTURE_DISABLED, Constants::RIGHTS_FUTURE_DISABLED_KEY]
        ]

        function_rights_array = function_rights[Constants::ITEMS_KEY]

        function_rights_array.each do |rights_array|
            rights_key_enum_array.each do |rights_enum, rights_key|
                if rights_array.include? rights_enum
                    rights_hash[rights_key] = true
                end
            end
        end

        render create_json_response(:ok, THIS_SOURCE, NO_SOURCE_DETAILS, rights_hash)
      rescue Exception => e
        render parse_exception_for_render(e)
      end
    end

    def get_employee_rights_userconfig
      invalid_key = check_params([:fct_code], [])
      return render bad_params_for_render(invalid_key) unless invalid_key.blank?

      begin
        response_string, string_pointer = ServiceLayerDll.get_employee_rights_userconfig(
          current_user.as_json,
          params[:fct_code]
        )
        ServiceLayerDll.free_string(string_pointer)

        render parse_response_string_for_render(response_string)
      rescue Exception => e
        render parse_exception_for_render(e)
      end
    end

    def get_permission
      invalid_key = check_params([], [:given_fct_code, :min_right, :mandant_id, :planarea_id, :subjectarea_id])
      return render bad_params_for_render(invalid_key) unless invalid_key.blank?

      begin
        response_string, string_pointer = ServiceLayerDll.get_permission(
          current_user.as_json,
          params[:given_fct_code].to_i,
          params[:min_right].to_i,
          params[:mandant_id].to_i,
          params[:planarea_id].to_i,
          params[:subjectarea_id].to_i
        )
        ServiceLayerDll.free_string(string_pointer)

        render parse_response_string_for_render(response_string)
      rescue Exception => e
        render parse_exception_for_render(e)
      end
    end

    def get_permission_right
      invalid_key = check_params([], [:given_fct_code, :mandant_id, :planarea_id, :subjectarea_id])
      return render bad_params_for_render(invalid_key) unless invalid_key.blank?

      begin
        response_string, string_pointer = ServiceLayerDll.get_permission_right(
          current_user.as_json,
          params[:given_fct_code].to_i,
          params[:mandant_id].to_i,
          params[:planarea_id].to_i,
          params[:subjectarea_id].to_i
        )
        ServiceLayerDll.free_string(string_pointer)

        render parse_response_string_for_render(response_string)
      rescue Exception => e
        render parse_exception_for_render(e)
      end
    end

    def get_permitted_planareas
      invalid_key = check_params([], [:given_fct_code])
      return render bad_params_for_render(invalid_key) unless invalid_key.blank?

      begin
        response_string, string_pointer = ServiceLayerDll.get_permitted_planareas(
          current_user.as_json,
          params[:given_fct_code].to_i
        )
        ServiceLayerDll.free_string(string_pointer)

        render parse_response_string_for_render(response_string)
      rescue Exception => e
        render parse_exception_for_render(e)
      end
    end
  end
end
